starcluster.cli

Package starcluster :: Module cli |
[hide private]
[frames] | no frames]

# Module cli

source code

StarCluster Command Line Interface:

starcluster [global-opts] action [action-opts] [<action-args> ...]

Version: 0.92rc1

Classes | [hide private]
| StarClusterCLI StarCluster Command Line Interface

Functions | [hide private]
main() | source code

Variables | [hide private]
| __description__ = ``'``\nStarCluster - (http://web.mit.edu/starclu``...``
| __package__ = ``'``starcluster``'``

Variables Details | [hide private]

  ### __description__ Value:
      '''
      StarCluster - (http://web.mit.edu/starcluster) (v. 0.92rc1)
      Software Tools for Academics and Researchers (STAR)
      Please submit bug reports to starcluster@mit.edu
      '''